==> haskell-bin-0.1.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bin
version:              0.1.4
visibility:           public
id:                   bin-0.1.4-5XowZxOlK6e1tykv0kQT94
key:                  bin-0.1.4-5XowZxOlK6e1tykv0kQT94
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  3a5b223b87670164b7c9f307ba3dec4c
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.4-5XowZxOlK6e1tykv0kQT94
depends:
    QuickCheck-2.14.3-D49gE8yyhJR3GOudg4cIYs base-4.17.2.1
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    fin-0.3.1-CZ4T3nXiE8cGUrc0JtnSKl
    hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt
    some-1.0.6-C8SVhXoLo1W43DiM5WqKp8

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bin-0.1.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bin
version:              0.1.4
visibility:           public
id:                   bin-0.1.4-ArwLSwqWyJjLUiT4aMDLIu
key:                  bin-0.1.4-ArwLSwqWyJjLUiT4aMDLIu
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  b335e9d82821906ccc00c45e3e2b9313
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bin-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.4-ArwLSwqWyJjLUiT4aMDLIu
depends:
    QuickCheck-2.14.3-E1wEMASCRcx3sbgPTZdgYJ base-4.17.2.1
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    fin-0.3.1-D39uEHQknhq3HXSWLmKY4S
    hashable-1.4.4.0-9qNl3SeJnhrLashClEgMWi
    some-1.0.6-BW0smRITBO31LwMrxpYAhK

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
